package com.aleena.hitunguang

import android.content.Intent
import android.net.Uri
import android.os.Bundle
import android.text.TextUtils
import com.aleena.hitunguang.WebActivity
import com.aleena.hitunguang.utils.FirebaseUtil
import com.aleena.hitunguang.utils.PictureUtil
import com.aleena.hitunguang.utils.getToken
import com.aleena.hitunguang.utils.impl.Constants
import com.aleena.hitunguang.utils.initPush
import com.aleena.hitunguang.versionName
import com.umeng.analytics.MobclickAgent
import io.flutter.app.FlutterActivity
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugins.GeneratedPluginRegistrant

class MainActivity : FlutterActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        GeneratedPluginRegistrant.registerWith(this)
        eventChannel = MethodChannel(flutterView, "$packageName/event")
        eventChannel?.setMethodCallHandler { methodCall, result ->
            when (methodCall.method) {
                "login" -> FirebaseUtil.login(this) {
                    result.success(it)
                }
                "logout" -> FirebaseUtil.logout()
                "toWeb" -> toWebAction(methodCall)
                "version" -> result.success(versionName())
                "token" -> getToken {
                    //获取token参数
                    initPush()
                    result.success(it)
                }
                "openPicture" -> PictureUtil.openPicture(this) {
                    result.success(it)
                }
                "toPrivacy" -> {
                    WebActivity.openMe(this, Constants.PRIVACY_URL)
                }
            }
        }
        checkNotify(intent)
    }

    override fun onNewIntent(data: Intent?) {
        super.onNewIntent(data)
        intent = data
        checkNotify(data)
    }

    /**
     * 通知打开事件
     */
    private fun checkNotify(data: Intent?) {
        val url = data?.getStringExtra("openUrl")
        if (TextUtils.isEmpty(url)) return
        eventChannel?.invokeMethod("saveEventTracking", 2)
        WebActivity.openMe(this, url ?: "")
    }


    private fun toWebAction(methodCall: MethodCall) {
        val map = methodCall.arguments as Map<String, Object>
        val openType = map["openType"] as Int
        val androidUrl = map["url"] as String
        val params = HashMap<String, Any>()
        params["tag"] = openType
        params["field1"] = androidUrl
        when (openType) {
            3 -> {
                params["field3"] = if (openGooglePlayStoreAppDetail(androidUrl)) "success" else "failed"
                eventChannel?.invokeMethod("saveEventGooglePlay", params)
            }
            2 -> {
                try {
                    val parse = Uri.parse(androidUrl)
                    val intent = Intent(Intent.ACTION_VIEW, parse)

                    startActivity(intent)
                    params["field3"] = "success"
                } catch (e: Exception) {
                    params["field3"] = "failed"
                }
                eventChannel?.invokeMethod("saveEventGooglePlay", params)
            }
            else -> WebActivity.openMe(this, androidUrl)
        }
    }

    companion object {
        var eventChannel: MethodChannel? = null
    }

    /**
     * 打开Google Play Store App
     */
    fun openGooglePlayStoreAppDetail(storeUrl: String): Boolean {
        try {
            if (TextUtils.isEmpty(storeUrl)) return false;
            val intent = Intent(Intent.ACTION_VIEW).apply {
                data = Uri.parse(storeUrl)
                setPackage("com.android.vending")
            }
            startActivity(intent)
            return true
        } catch (e: Exception) {
            e.printStackTrace()
            //打开浏览器
            WebActivity.openMe(this, storeUrl)
        }
        return false
    }

    override fun onResume() {
        super.onResume()
        MobclickAgent.onResume(this)
    }

    override fun onPause() {
        super.onPause()
        MobclickAgent.onPause(this)
    }
}
